/*
  property.cpp

  Copyright (c) 2021 Kevin Matz (kevin.matz@gmail.com)

  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
  in the Software without restriction, including without limitation the rights
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in all
  copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  SOFTWARE.
*/
#include "parameter.h"

namespace RDM {

/**
 * @brief Property::Property
 */
Parameter::Parameter()
{
}


/**
 * @brief Parameter::~Parameter
 */
Parameter::~Parameter()
{
}


/**
 * @brief Parameter::disc
 * @param message
 * @param response
 */
void Parameter::disc(const MsgPtr message, MsgPtr response) const
{
  if (!discover_)
    {
      response->nak(NR_UNSUPPORTED_COMMAND_CLASS);
      return;
    }

  discover_(message, response);
}


/**
 * @brief Parameter::get
 * @param message
 * @param response
 */
void Parameter::get(const MsgPtr message, MsgPtr response) const
{
  if (!getter_){
      response->nak(NR_UNSUPPORTED_COMMAND_CLASS);
      return;
    }

  getter_(message, response);
}


/**
 * @brief Parameter::set
 * @param message
 * @param response
 */
void Parameter::set(const MsgPtr message, MsgPtr response) const
{
  if (!setter_)
    {
      response->nak(NR_UNSUPPORTED_COMMAND_CLASS);
      return;
    }

  setter_(message, response);
}


/**
 * @brief Parameter::discAction
 * @param action
 */
void Parameter::discAction(const PidAction action)
{
  discover_ = action;
};


/**
 * @brief Parameter::getAction
 * @param action
 */
void Parameter::getAction(const PidAction action)
{
  getter_ = action;
};


/**
 * @brief Parameter::setAction
 * @param action
 */
void Parameter::setAction(const PidAction action)
{
  setter_ = action;
};

} // namespace RDM
